==> pochy-0.3.1-src.tar.gz: pochy.h <==
// Pochy.h : POCHY AvP[ṼC wb_[ t@C

//



#if !defined(AFX_MOO_H__B0C245C4_42EA_11D5_B88C_00008659960F__INCLUDED_)

#define AFX_MOO_H__B0C245C4_42EA_11D5_B88C_00008659960F__INCLUDED_



#if _MSC_VER > 1000

#pragma once

#endif // _MSC_VER > 1000



#ifndef __AFXWIN_H__

	#error include 'stdafx.h' before including this file for PCH

#endif



#include <afxtempl.h>

#include "Skin.h"

#include "resource.h"       // C V{

#include "draftframe.h"

#include "MimeEncode.h"

#include "Plugin.h"



#define WM_END (WM_USER+101)

#define WM_PROGCREATE (WM_USER+102)

#define WM_PROGDESTROY (WM_USER+103)

#define WM_MAILTO (WM_USER+104)

#define WM_TITLE (WM_USER+105)

#define DEF_MULTI_HEIGHT (60)			// height of multipart view

#define HT_ATTACHED_HEIGHT (30)			// default height os attached file view in draftframe

#define HT_SPLIT_LINE (7)				// width of splitter line

#define HT_SPLIT_FRAME (2)				// width of splitter frame

#define DEF_ADDRESS_HEIGHT (120)		// default height of address view in draftframe

#define DEF_HEADER_HEIGHT (50)			// default height of header view in mainframe

#define READBUFSIZE (19)

#define WIDTH_ICON_MAIN (29)			// width of toolbar button in mainframe

#define HEIGHT_ICON_MAIN (44)			// height of toolbar button in mainframe

#define WIDTH_ICON_DRAFT (29)			// width of toolbar button in draftframe

#define HEIGHT_ICON_DRAFT (44)			// height of toolbar button in mainframe

#define DEF_TXT_COLOR_R (0)				// default color of text

#define DEF_TXT_COLOR_G (0)

#define DEF_TXT_COLOR_B (0)

#define DEF_BKG_COLOR_R (255)			// default color of background

#define DEF_BKG_COLOR_G (255)

#define DEF_BKG_COLOR_B (255)

#define DEF_HEADER_INFO_COLOR_R (128)	// default color of header info

#define DEF_HEADER_INFO_COLOR_G (255)

#define DEF_HEADER_INFO_COLOR_B (0)

#define DEF_BOXNAME_INBOX _T("M")		// default name of inbox

#define DEF_BOXNAME_OUTBOX _T("Mς")	// default name of outbox

#define DEF_BOXNAME_DRAFT _T("e")		// default name of draft

#define DEF_BOXNAME_TRASH _T("S~")		// default name of trash

#ifdef _IPV6_

#define X_MAILER "Pochy 0.2.1b IPv6 ready"	// x-mailer of ipv6 ready version

#define VERSION "Pochy 0.2.1b IPv6 ready"	// version info of ipv6 ready version

#else

#define X_MAILER "Pochy 0.3.1"				// x-mailer of normal version

#define VERSION "Pochy 0.3.1"				// version info of ipv6 ready version

#endif

#define COPYRIGHT "Copyright (C) 2003-2005 Pochy project team"

#define CONTRIBUTORS "\

Portions of this software are Copyright (C) 2005 by moogv\r\n\

  Portions of this software are Copyright (C) 2003-2004 by minamina\r\n\

Portions of this software are Copyright (C) 2003 by xken\r\n\

Portions of this software are Copyright (C) 2003 by ajishio_taro\r\n"

#define DEF_TIME_ZONE "+0900"			// default time zone

#define DEF_TIME_FORMAT "%Y %b %d %H:%M:%S "

#define DEF_POP_PORT "110"				// default pop port

#define DEF_SMTP_PORT "25"				// default smtp port

#define BUF_LENGTH (255)				// default buffer max length

#define LISTCTRL_BUF_LENGTH (2048)

#define FILTER_INSTRUCTION "\

# ݂̂ƂA[̐U蕪ݒGUIł͂ł܂B\r\n\

# 蓮Őݒt@CKv܂B \r\n\

#\r\n\

# ݒ:\r\n\

#\r\n\

# Subjectpochyꍇ -> pochytH_ɕۑ\r\n\

# Fromhoge@hoge.comꍇ -> hogetH_ɕۑ\r\n\

#\r\n\

\\pochy\r\n\

Subject=pochy\r\n\

#\r\n\

\\hoge\r\n\

From=hoge@hoge.com\r\n\

#\r\n\

# w肵tH_݂Ȃꍇ͎Iɍ쐬܂B\r\n\

# `ƒ`̊Ԃ͏L̂悤ɕK#ŋ؂ĂB\r\n\

# ݂̂ƂAU蕪ɂ̓wb_񂵂pł܂B\r\n\

# ҏWA㏑ۑĂB\r\n\

#\r\n\

# ̑A\r\n\

# - ̃tH_ɐU蕪\r\n\

# - K\g\r\n\

# ɂĂhttp://pochy.sourceforge.jp̃hLgQƂB\r\n"



#define WM_USER_NOTIFYICON (WM_APP + 100)

#define TOOLBAR_MAIN_FILENAME _T("\\skin\\toolbar_main.bmp")

#define TASKTRAY_ICON_FILENAME _T("\\skin\\tasktray.ico")

#define TASKTRAY_ANIMATION_FILENAME _T("\\skin\\tasktrayanimation.bmp")

#define TASKTRAY_ANIMATION_TIMER_ID (200)

#define NUMBER_OF_TOOLBAR_MAIN_ICON (10)



#define DEF_HEADER_TEMPLATE "\

ol: %f  : %t\r\n\

: %s  t: %d\r\n\

x-mailer: %[x-mailer]"



#define DEF_REPLY_TEMPLATE "\r\n\

On %d\r\n\

%f wrote:\r\n\

\r\n\

%Q\r\n\

%S"



#define DEF_FORWARD_TEMPLATE "\r\n\

Forwarded by %a\r\n\

----- Original Message -----\r\n\

From: %f\r\n\

To: %t\r\n\

---\r\n\

\r\n\

%M"



#define DEF_DRAFT_TEMPLATE "\r\n\

\

%S"



#define get_app CPochyApp* app = (CPochyApp*)AfxGetApp()



/////////////////////////////////////////////////////////////////////////////

// CPochyApp:

// ̃NX̓̒`ɊւĂ Pochy.cpp t@CQƂĂB

//



class CPochyApp : public CWinApp

{

public:

	CPochyApp();



// I[o[Ch

	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B

	//{{AFX_VIRTUAL(CPochyApp)

	public:

	virtual BOOL InitInstance();

	virtual int ExitInstance();

	//}}AFX_VIRTUAL



// Cve[V

	//{{AFX_MSG(CPochyApp)

	afx_msg void OnAppAbout();

	//}}AFX_MSG

	DECLARE_MESSAGE_MAP()

private:

	CSingleDocTemplate* pDoc2Template;

	CSingleDocTemplate* pDoc1Template;

public:

	CPluginManager m_pluginManager;

	void CreateDraftFrame(CString acocunt);

	BOOL LoadSkinProfile(LPCTSTR skinIniFile);

// oϐ

	CArray<CDraftFrame *, CDraftFrame *> m_draft_array;

	CString m_gpg_passphrase;

	CString m_keyword;			// this is for consecutive search

	CString m_app_path;			// this is path for directory in which pochy.exe is

	CString m_time_zone_offset;	// this effect summary date and so on

	BOOL m_retrieving;

	BOOL m_gpg_enable;

	BOOL m_ipv6_enable;

	CMimeEncode m_me;

	CSkin m_skin;

};



/////////////////////////////////////////////////////////////////////////////



//{{AFX_INSERT_LOCATION}}

// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B



#endif // !defined(AFX_MOO_H__B0C245C4_42EA_11D5_B88C_00008659960F__INCLUDED_)

==> pochy-0.3.2b-src.tar.gz: pochy.h <==
// Pochy.h : POCHY AvP[ṼC wb_[ t@C
//

#if !defined(AFX_MOO_H__B0C245C4_42EA_11D5_B88C_00008659960F__INCLUDED_)
#define AFX_MOO_H__B0C245C4_42EA_11D5_B88C_00008659960F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#ifndef __AFXWIN_H__
	#error include 'stdafx.h' before including this file for PCH
#endif

#include <afxtempl.h>
#include "Skin.h"
#include "resource.h"       // C V{
#include "draftframe.h"
#include "MimeEncode.h"
#include "Plugin.h"

#define WM_END (WM_USER+101)
#define WM_PROGCREATE (WM_USER+102)
#define WM_PROGDESTROY (WM_USER+103)
#define WM_MAILTO (WM_USER+104)
#define WM_TITLE (WM_USER+105)
#define DEF_MULTI_HEIGHT (60)			// height of multipart view
#define HT_ATTACHED_HEIGHT (30)			// default height os attached file view in draftframe
#define HT_SPLIT_LINE (7)				// width of splitter line
#define HT_SPLIT_FRAME (2)				// width of splitter frame
#define DEF_ADDRESS_HEIGHT (120)		// default height of address view in draftframe
#define DEF_HEADER_HEIGHT (50)			// default height of header view in mainframe
#define READBUFSIZE (19)
#define WIDTH_ICON_MAIN (29)			// width of toolbar button in mainframe
#define HEIGHT_ICON_MAIN (44)			// height of toolbar button in mainframe
#define WIDTH_ICON_DRAFT (29)			// width of toolbar button in draftframe
#define HEIGHT_ICON_DRAFT (44)			// height of toolbar button in mainframe
#define DEF_TXT_COLOR_R (0)				// default color of text
#define DEF_TXT_COLOR_G (0)
#define DEF_TXT_COLOR_B (0)
#define DEF_BKG_COLOR_R (255)			// default color of background
#define DEF_BKG_COLOR_G (255)
#define DEF_BKG_COLOR_B (255)
#define DEF_HEADER_INFO_COLOR_R (128)	// default color of header info
#define DEF_HEADER_INFO_COLOR_G (255)
#define DEF_HEADER_INFO_COLOR_B (0)
#define DEF_BOXNAME_INBOX _T("M")		// default name of inbox
#define DEF_BOXNAME_OUTBOX _T("Mς")	// default name of outbox
#define DEF_BOXNAME_DRAFT _T("e")		// default name of draft
#define DEF_BOXNAME_TRASH _T("S~")		// default name of trash
#ifdef _IPV6_
#define X_MAILER "Pochy 0.2.1b IPv6 ready"	// x-mailer of ipv6 ready version
#define VERSION "Pochy 0.2.1b IPv6 ready"	// version info of ipv6 ready version
#else
#define X_MAILER "Pochy 0.3.2b"				// x-mailer of normal version
#define VERSION "Pochy 0.3.2b"				// version info of ipv6 ready version
#endif
#define COPYRIGHT "Copyright (C) 2003-2005 Pochy project team"
#define CONTRIBUTORS "\
Portions of this software are Copyright (C) 2005 by moogv\r\n\
  Portions of this software are Copyright (C) 2003-2004 by minamina\r\n\
Portions of this software are Copyright (C) 2003 by xken\r\n\
Portions of this software are Copyright (C) 2003 by ajishio_taro\r\n"
#define DEF_TIME_ZONE "+0900"			// default time zone
#define DEF_TIME_FORMAT "%Y %b %d %H:%M:%S "
#define DEF_POP_PORT "110"				// default pop port
#define DEF_SMTP_PORT "25"				// default smtp port
#define BUF_LENGTH (255)				// default buffer max length
#define LISTCTRL_BUF_LENGTH (2048)
#define FILTER_INSTRUCTION "\
# ݂̂ƂA[̐U蕪ݒGUIł͂ł܂B\r\n\
# 蓮Őݒt@CKv܂B \r\n\
#\r\n\
# ݒ:\r\n\
#\r\n\
# Subjectpochyꍇ -> pochytH_ɕۑ\r\n\
# Fromhoge@hoge.comꍇ -> hogetH_ɕۑ\r\n\
#\r\n\
\\pochy\r\n\
Subject=pochy\r\n\
#\r\n\
\\hoge\r\n\
From=hoge@hoge.com\r\n\
#\r\n\
# w肵tH_݂Ȃꍇ͎Iɍ쐬܂B\r\n\
# `ƒ`̊Ԃ͏L̂悤ɕK#ŋ؂ĂB\r\n\
# ݂̂ƂAU蕪ɂ̓wb_񂵂pł܂B\r\n\
# ҏWA㏑ۑĂB\r\n\
#\r\n\
# ̑A\r\n\
# - ̃tH_ɐU蕪\r\n\
# - K\g\r\n\
# ɂĂhttp://pochy.sourceforge.jp̃hLgQƂB\r\n"

#define WM_USER_NOTIFYICON (WM_APP + 100)
#define TOOLBAR_MAIN_FILENAME _T("\\skin\\toolbar_main.bmp")
#define TASKTRAY_ICON_FILENAME _T("\\skin\\tasktray.ico")
#define TASKTRAY_ANIMATION_FILENAME _T("\\skin\\tasktrayanimation.bmp")
#define TASKTRAY_ANIMATION_TIMER_ID (200)
#define NUMBER_OF_TOOLBAR_MAIN_ICON (10)

#define DEF_HEADER_TEMPLATE "\
ol: %f  : %t\r\n\
: %s  t: %d\r\n\
x-mailer: %[x-mailer]"

#define DEF_REPLY_TEMPLATE "\r\n\
On %d\r\n\
%f wrote:\r\n\
\r\n\
%Q\r\n\
%S"

#define DEF_FORWARD_TEMPLATE "\r\n\
Forwarded by %a\r\n\
----- Original Message -----\r\n\
From: %f\r\n\
To: %t\r\n\
---\r\n\
\r\n\
%M"

#define DEF_DRAFT_TEMPLATE "\r\n\
\
%S"

#define get_app CPochyApp* app = (CPochyApp*)AfxGetApp()

/////////////////////////////////////////////////////////////////////////////
// CPochyApp:
// ̃NX̓̒`ɊւĂ Pochy.cpp t@CQƂĂB
//

class CPochyApp : public CWinApp
{
public:
	CPochyApp();

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CPochyApp)
	public:
	virtual BOOL InitInstance();
	virtual int ExitInstance();
	//}}AFX_VIRTUAL

// Cve[V
	//{{AFX_MSG(CPochyApp)
	afx_msg void OnAppAbout();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
private:
	CSingleDocTemplate* pDoc2Template;
	CSingleDocTemplate* pDoc1Template;
public:
	CPluginManager m_pluginManager;
	void CreateDraftFrame(CString acocunt);
	BOOL LoadSkinProfile(LPCTSTR skinIniFile);
// oϐ
	CArray<CDraftFrame *, CDraftFrame *> m_draft_array;
	CString m_gpg_passphrase;
	CString m_keyword;			// this is for consecutive search
	CString m_app_path;			// this is path for directory in which pochy.exe is
	CString m_time_zone_offset;	// this effect summary date and so on
	BOOL m_retrieving;
	BOOL m_gpg_enable;
	BOOL m_ipv6_enable;
	CMimeEncode m_me;
	CSkin m_skin;
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MOO_H__B0C245C4_42EA_11D5_B88C_00008659960F__INCLUDED_)
